pub struct StateDescriptor {
pub dir: PathBuf,
pub stages: Vec<StageState>,
pub state: QuestState,
pub can_skip: bool,
pub behind_origin: bool,
}Fields
dir: PathBufstages: Vec<StageState>state: QuestStatecan_skip: boolbehind_origin: boolTrait Implementations
Sourceimpl Clone for StateDescriptor
impl Clone for StateDescriptor
Sourcefn clone(&self) -> StateDescriptor
fn clone(&self) -> StateDescriptor
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for StateDescriptor
impl<'de> Deserialize<'de> for StateDescriptor
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl NamedType for StateDescriptor
impl NamedType for StateDescriptor
fn sid() -> SpectaID
Sourcefn named_data_type(
type_map: &mut TypeMap,
generics: &[DataType],
) -> NamedDataType
fn named_data_type( type_map: &mut TypeMap, generics: &[DataType], ) -> NamedDataType
this is equivalent to Type::inline but returns a NamedDataType instead.
Sourcefn definition_named_data_type(type_map: &mut TypeMap) -> NamedDataType
fn definition_named_data_type(type_map: &mut TypeMap) -> NamedDataType
this is equivalent to [Type::definition] but returns a NamedDataType instead.
Sourceimpl Serialize for StateDescriptor
impl Serialize for StateDescriptor
Sourceimpl Type for StateDescriptor
impl Type for StateDescriptor
Sourcefn inline(type_map: &mut TypeMap, generics: Generics<'_>) -> DataType
fn inline(type_map: &mut TypeMap, generics: Generics<'_>) -> DataType
Returns the definition of a type using the provided generics. Read more
Sourcefn reference(type_map: &mut TypeMap, generics: &[DataType]) -> Reference
fn reference(type_map: &mut TypeMap, generics: &[DataType]) -> Reference
Generates a datatype corresponding to a reference to this type,
as determined by its category. Getting a reference to a type implies that
it should belong in the type map (since it has to be referenced from somewhere),
so the output of
definition will be put into the type map.impl Flatten for StateDescriptor